@@ -14,11 +14,22 @@ httpget_package_r <- function(pkgpath, requri){
     
     if(!length(reqobject)){
       res$checkmethod();
-      res$sendlist(ls(paste("package", reqpackage, sep=":")));
+      ns <- paste("package", reqpackage, sep=":")
+      res$sendlist(ls(ns))
+      #HTML:
+      #indexdata <- data.frame(name = ls(ns), stringsAsFactors=FALSE)
+      #indexdata$size <- unname(vapply(indexdata$name, function(x){object.size(get(x, ns))}, numeric(1)))
+      #send_index(indexdata)
     }
     
-    #Get object. Throws error if object does not exist.
-    myobject <- get(reqobject, paste("package", reqpackage, sep=":"), inherits=FALSE);
+    #Get object. Try package namespace first (won't work for lazy data)
+    ns <- asNamespace(reqpackage)
+    myobject <- if(exists(reqobject, ns, inherits = FALSE)){
+      get(reqobject, envir = ns, inherits = FALSE)
+    } else {
+      #Fall back on exported env
+      get(reqobject, paste("package", reqpackage, sep=":"), inherits = FALSE)
+    }
     
     #only GET/POST allowed
     res$checkmethod(c("GET", "POST"));    
